mirror of https://lore.kernel.org/lkml/
 help / color / mirror / Atom feed
From: Hemanth Selam <hemanth.selam@gmail.com>
To: Takashi Iwai <tiwai@suse.com>, Jaroslav Kysela <perex@perex.cz>
Cc: linux-sound@vger.kernel.org, linux-kernel@vger.kernel.org,
	Takashi Sakamoto <o-takashi@sakamocchi.jp>,
	Clemens Ladisch <clemens@ladisch.de>
Subject: [PATCH v2 15/23] ALSA: cs46xx: fix typos in comments
Date: Tue, 15 Sep 2026 14:14:16 +0530	[thread overview]
Message-ID: <20260915084424.1007757-16-hemanth.selam@gmail.com> (raw)
In-Reply-To: <20260915084424.1007757-1-hemanth.selam@gmail.com>

Correct spelling mistakes in comments. No functional change.

Signed-off-by: Hemanth Selam <hemanth.selam@gmail.com>
---
 sound/pci/cs46xx/cs46xx_lib.c       | 6 +++---
 sound/pci/cs46xx/dsp_spos_scb_lib.c | 8 ++++----
 2 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/sound/pci/cs46xx/cs46xx_lib.c b/sound/pci/cs46xx/cs46xx_lib.c
index 19a6927c079d..a16586f7d913 100644
--- a/sound/pci/cs46xx/cs46xx_lib.c
+++ b/sound/pci/cs46xx/cs46xx_lib.c
@@ -315,7 +315,7 @@ int snd_cs46xx_download(struct snd_cs46xx *chip,
 	dst = chip->region.idx[bank+1].remap_addr + offset;
 	len /= sizeof(u32);
 
-	/* writel already converts 32-bit value to right endianess */
+	/* writel already converts 32-bit value to right endianness */
 	while (len-- > 0) {
 		writel(*src++, dst);
 		dst += sizeof(u32);
@@ -474,7 +474,7 @@ int snd_cs46xx_clear_BA1(struct snd_cs46xx *chip,
 	dst = chip->region.idx[bank+1].remap_addr + offset;
 	len /= sizeof(u32);
 
-	/* writel already converts 32-bit value to right endianess */
+	/* writel already converts 32-bit value to right endianness */
 	while (len-- > 0) {
 		writel(0, dst);
 		dst += sizeof(u32);
@@ -3039,7 +3039,7 @@ static int snd_cs46xx_chip_init(struct snd_cs46xx *chip)
 #endif
 
 	/*
-	 *  Assert the vaid frame signal so that we can start sending commands
+	 *  Assert the valid frame signal so that we can start sending commands
 	 *  to the AC97 codec.
 	 */
 	snd_cs46xx_pokeBA0(chip, BA0_ACCTL, ACCTL_VFRM | ACCTL_ESYN | ACCTL_RSTN);
diff --git a/sound/pci/cs46xx/dsp_spos_scb_lib.c b/sound/pci/cs46xx/dsp_spos_scb_lib.c
index fd19365026b4..71eee5cb478f 100644
--- a/sound/pci/cs46xx/dsp_spos_scb_lib.c
+++ b/sound/pci/cs46xx/dsp_spos_scb_lib.c
@@ -160,15 +160,15 @@ void cs46xx_dsp_remove_scb (struct snd_cs46xx *chip, struct dsp_scb_descriptor *
 {
 	struct dsp_spos_instance * ins = chip->dsp_spos_instance;
 
-	/* check integrety */
+	/* check integrity */
 	if (snd_BUG_ON(scb->index < 0 ||
 		       scb->index >= ins->nscb ||
 		       (ins->scbs + scb->index) != scb))
 		return;
 
 #if 0
-	/* can't remove a SCB with childs before 
-	   removing childs first  */
+	/* can't remove a SCB with children before
+	   removing children first  */
 	if (snd_BUG_ON(scb->sub_list_ptr != ins->the_null_scb ||
 		       scb->next_scb_ptr != ins->the_null_scb))
 		goto _end;
@@ -1656,7 +1656,7 @@ int  cs46xx_dsp_disable_spdif_out (struct snd_cs46xx *chip)
 		return -EBUSY;
 	}
 
-	/* check integrety */
+	/* check integrity */
 	if (snd_BUG_ON(!ins->asynch_tx_scb))
 		return -EINVAL;
 	if (snd_BUG_ON(!ins->spdif_pcm_input_scb))
-- 
2.48.1


  parent reply	other threads:[~2026-09-15  8:45 UTC|newest]

Thread overview: 25+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2026-09-15  8:44 [PATCH v2 00/23] ALSA: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 01/23] ALSA: core: seq: oss: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 02/23] ALSA: hda: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 03/23] ALSA: usb-audio: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 04/23] ALSA: i2c: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 05/23] ALSA: emu10k1: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 06/23] ALSA: emux: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 07/23] ALSA: firewire: bebob: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 08/23] ALSA: opti9xx: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 09/23] ALSA: hal2: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 10/23] ALSA: ppc: tumbler: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 11/23] ALSA: ac97: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 12/23] ALSA: au88x0: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 13/23] ALSA: aw2: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 14/23] ALSA: cs4281: " Hemanth Selam
2026-09-15  8:44 ` Hemanth Selam [this message]
2026-09-15  8:44 ` [PATCH v2 16/23] ALSA: echoaudio: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 17/23] ALSA: lx6464es: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 18/23] ALSA: pcxhr: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 19/23] ALSA: riptide: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 20/23] ALSA: rme32: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 21/23] ALSA: hdsp: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 22/23] ALSA: trident: " Hemanth Selam
2026-09-15  8:44 ` [PATCH v2 23/23] ALSA: vx: " Hemanth Selam
2026-09-15 10:08 ` [PATCH v2 00/23] ALSA: " Takashi Iwai

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260915084424.1007757-16-hemanth.selam@gmail.com \
    --to=hemanth.selam@gmail.com \
    --cc=clemens@ladisch.de \
    --cc=linux-kernel@vger.kernel.org \
    --cc=linux-sound@vger.kernel.org \
    --cc=o-takashi@sakamocchi.jp \
    --cc=perex@perex.cz \
    --cc=tiwai@suse.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox

all inboxes | Powered by JetHome®